@@ -8,12 +8,12 @@ from urllib.parse import urlencode
 from bravado.requests_client import Authenticator
 
 
-MAPPER           = 'swg_mapper.json'
-QUERY_PARAMS     = ['uuids', 'txids', 'identifiers', 'states']
-
-
 class APIKeyAuthenticator(Authenticator):
 
+    MAPPER           = "swg_mapper.json"
+    QUERY_PARAMS     = tuple("uuids", "txids", "identifiers", "states")
+
+
     def __init__(
         self,
         host: str,
@@ -23,23 +23,26 @@ class APIKeyAuthenticator(Authenticator):
 
         super(APIKeyAuthenticator, self).__init__(host)
 
-        self.host = host
+        self.host       = host
         self.access_key = access_key
         self.secret_key = secret_key
 
+
     def matches(self, url):
-        return MAPPER not in url
+        return APIKeyAuthenticator.MAPPER not in url
+
 
     def apply(self, request):
         payload = self.generate_payload(request)
 
-        request.headers['User-Agent'     ] = "ujhin's Upbit SDKs"
-        request.headers['Accept-Encoding'] = 'gzip, deflate'
-        request.headers['Accept'         ] = '*/*'
-        request.headers['Connection'     ] = 'keep-alive'
-        request.headers['Authorization'  ] = payload
+        request.headers["User-Agent"     ] = "ujhin's Upbit SDKs"
+        request.headers["Accept-Encoding"] = "gzip, deflate"
+        request.headers["Accept"         ] = "*/*"
+        request.headers["Connection"     ] = "keep-alive"
+        request.headers["Authorization"  ] = payload
         return request
 
+
     def generate_payload(self, request):
         params = request.params
         data = request.data
@@ -57,20 +60,21 @@ class APIKeyAuthenticator(Authenticator):
             sha512.update(query.encode())
             query_hash = sha512.hexdigest()
 
-            payload['query_hash'    ] = query_hash
-            payload['query_hash_alg'] = 'SHA512'
+            payload["query_hash"    ] = query_hash
+            payload["query_hash_alg"] = "SHA512"
 
         jwt_token = jwt.encode(payload, self.secret_key)
         authorize_token = f"Bearer {jwt_token}"
         return authorize_token
 
+
     def generate_query(self, params):
         query = urlencode({
             k: v
             for k, v in params.items()
-            if k not in QUERY_PARAMS
+            if k.lower() not in APIKeyAuthenticator.QUERY_PARAMS
         })
-        for query_param in QUERY_PARAMS:
+        for query_param in APIKeyAuthenticator.QUERY_PARAMS:
             if params.get(query_param):
                 param = params.pop(query_param)
                 params[f"{query_param}[]"] = param
