@@ -6,12 +6,6 @@ import json
 from typing import Union, List
 
 
-WEBSOCKET_URI = "wss://api.upbit.com/websocket/v1"
-
-FIELD_TYPES   = ['ticker', 'trade', 'orderbook']
-FIELD_FORMATS = ['SIMPLE', 'DEFAULT']
-
-
 class UpbitWebSocket:
     """
     Upbit WebSocket Client
@@ -26,6 +20,11 @@ class UpbitWebSocket:
     - Official Support Email: open-api@upbit.com
     """
 
+    WEBSOCKET_URI = "wss://api.upbit.com/websocket/v1"
+    FIELD_TYPES   = tuple("ticker", "trade", "orderbook")
+    FIELD_FORMATS = tuple("SIMPLE", "DEFAULT")
+
+
     def __init__(
         self,
         uri: Union[str] = None,
@@ -33,13 +32,14 @@ class UpbitWebSocket:
         ping_timeout: Union[int, float] = None
     ):
 
-        self.__uri = uri if uri else WEBSOCKET_URI
+        self.__uri = uri if uri else UpbitWebSocket.WEBSOCKET_URI
         self.__conn = None
         self.connect(
             ping_interval=ping_interval,
             ping_timeout=ping_timeout
         )
 
+
     @property
     def URI(self):
         return self.__uri
@@ -56,6 +56,7 @@ class UpbitWebSocket:
     def Connection(self, conn):
         self.__conn = conn
 
+
     def connect(
         self,
         ping_interval: Union[int, float] = None,
@@ -75,14 +76,17 @@ class UpbitWebSocket:
             ping_timeout=ping_timeout
         )
 
-    async def ping(self):
+
+    async def ping(self, decode: str = "utf8"):
         """
         Client to Server PING
         """
         async with self as conn:
-            await conn.send('PING')
+            await conn.send("PING")
             recv = await conn.recv()
-            return json.loads(recv)
+            pong = recv.decode(decode)
+            return json.loads(pong)
+
 
     @staticmethod
     def generate_orderbook_codes(
@@ -104,6 +108,7 @@ class UpbitWebSocket:
         ] if counts else currencies
         return codes
 
+
     @staticmethod
     def generate_type_field(
         type: str,
@@ -127,8 +132,9 @@ class UpbitWebSocket:
 
         field = {}
 
-        if type in FIELD_TYPES:
-            field["type"] = type
+        t = type.lower()
+        if t in UpbitWebSocket.FIELD_TYPES:
+            field["type"] = t
         else:
             raise ValueError("'type' is not available")
 
@@ -142,6 +148,7 @@ class UpbitWebSocket:
 
         return field
 
+
     @staticmethod
     def generate_payload(
         type_fields: Union[List[dict]],
@@ -167,11 +174,12 @@ class UpbitWebSocket:
         payload.extend(type_fields)
 
         fmt = format.upper()
-        fmt = fmt if fmt in FIELD_FORMATS else 'DEFAULT'
+        fmt = fmt if fmt in UpbitWebSocket.FIELD_FORMATS else "DEFAULT"
         payload.append({"format": fmt})
 
         return json.dumps(payload)
 
+
     async def __aenter__(self):
         return await self.Connection.__aenter__()
 
